@@ -1,13 +1,12 @@
 from packaging_tutorial.lanedetection.Config import ConfigTrain
-import packaging_tutorial.lanedetection.utilss
 from packaging_tutorial.lanedetection.model.deeplab import DeepLab
 import numpy as np
 import pandas as pd
 import cv2
 import torch
 from torchvision import transforms
-from packaging_tutorial.lanedetection.utilss.data import decodePredicts
-import aspp
+from packaging_tutorial.lanedetection.utils.data import decodePredicts
+
 def inference():
     cfg = ConfigTrain()
     print('please input your device: cpu or cuda')
@@ -15,15 +14,15 @@ def inference():
     device = torch.device(device)
     net = DeepLab(num_classes=cfg.NUM_CLASSES)
     print('please input your pretrain weight path:')
-    weight_path = input()
-    # weight_path = 'F:/pycharm/xiangmu_week7/weight/road04_4'
+    # weight_path = input()
+    weight_path = 'F:/pycharm/xiangmu_week7/weight/road04_4'
     net.load_state_dict(torch.load(weight_path))
     net = net.to(device)
     net.eval()
     print('please input your picture path:')
-    input_image_path = input()
-    input_image = cv2.imread(input_image_path)
-    # input_image = cv2.imread('C:/Users/Administrator/Desktop/170927_064448134_Camera_5.jpg')
+    # input_image_path = input()
+    # input_image = cv2.imread(input_image_path)
+    input_image = cv2.imread('C:/Users/Administrator/Desktop/170927_064448134_Camera_5.jpg')
     input_image = cv2.resize(input_image, (1024,384) )
     import matplotlib.pyplot as plt
     plt.imshow(input_image)
